@@ -33,6 +33,10 @@
 #include <time.h> // time()
 #include "zlib.h"
 
+#ifndef QT_STAT_LNK
+#       define QT_STAT_LNK 0120000
+#endif // QT_STAT_LNK
+
 ////////////////////////////////////////////////////////////////////////
 /////////////////////////// K7Zip //////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////
